facilities.hpp

The facilities.hpp includes the headers in the facilities folder.

#### Usage

#include <boost/preprocessor/facilities.hpp>

#### Includes

- <boost/preprocessor/facilities/apply.hpp>
- <boost/preprocessor/facilities/empty.hpp>
- <boost/preprocessor/facilities/expand.hpp>
- <boost/preprocessor/facilities/identity.hpp>
- <boost/preprocessor/facilities/intercept.hpp>
- <boost/preprocessor/facilities/overload.hpp> (v)

© Copyright Housemarque Oy 2002
© Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)